skvai package — skvai 0.1.0 documentation

# skvai package

## Subpackages

- skvai.tasks package
  - Submodules
  - skvai.tasks.classification module
    - `Task`
      - `Task.load_data()`
      - `Task.set_target()`
      - `Task.train_and_output()`
  - skvai.tasks.clustering module
    - `cluster()`
  - skvai.tasks.regression module
    - `regress()`
  - Module contents
    - `Task`
      - `Task.load_data()`
      - `Task.set_target()`
      - `Task.train_and_output()`
    - `cluster()`
    - `regress()`
- skvai.utils package
  - Submodules
  - skvai.utils.data_loader module
    - `DataLoader`
      - `DataLoader.load_csv()`
      - `DataLoader.preview()`
    - `load_data()`
  - Module contents

## Submodules

## skvai.cli module

## skvai.core module

class skvai.core.CSVData(df: DataFrame, target_column: str = None)

  Bases: `object`

  classmethod from_csv(filepath: str, target_column: str = None)

## skvai.data_loader module

class skvai.data_loader.DataLoader

  Bases: `object`

  load_csv(file_path)
  preview(rows=5)

skvai.data_loader.load_data(file_path)

## Module contents